Documentation
¶
Index ¶
Constants ¶
const ( CONCAT arrayMergeStrategy = iota REPLACE )
Variables ¶
This section is empty.
Functions ¶
func RegisterGob ¶
func RegisterGob(value any)
RegisterGob recursively registers a value. Useful when dealing with polymorphic values that need to be written across the wire.
May need Jesus for this one
Types ¶
type Reflector ¶
type Reflector struct {
// contains filtered or unexported fields
}
func NewReflector ¶
func (*Reflector) ArrayStrategy ¶
func (r *Reflector) ArrayStrategy(ams arrayMergeStrategy)
func (*Reflector) Merge ¶
Merges 2 structs, field by field replacing all existing field in the right structure into the left. If left is nil returns right. If the types don't match up, returns right
func (*Reflector) PrintValue ¶
Print a value as code. Very useful for code generation when a library provides the types being generated
Click to show internal directories.
Click to hide internal directories.